@@ -12,8 +12,10 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   along with this software; see the file COPYING.  If not, a copy
+   can be downloaded from http://www.gnu.org/licenses/gpl.html, or
+   obtained by writing to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 /*------------------------------------------------------------*/
 
@@ -22,6 +24,16 @@
 #ifndef PANORAMA_H
 #define PANORAMA_H
 
+#if defined _WIN32 && defined PANO13_DLL
+#if defined pano13_EXPORTS
+#define PANO13_IMPEX __declspec(dllexport)
+#else
+#define PANO13_IMPEX __declspec(dllimport)
+#endif
+#else
+#define PANO13_IMPEX
+#endif
+
 #include "pt_stdint.h"
 #include "version.h"
 #include "panotypes.h"
@@ -49,15 +61,6 @@ typedef unsigned char Boolean;
   #endif
 #endif
 
-// Create a definition if we're on a Macintosh:
-#ifndef __Mac__
-  #if (defined(macintosh) || defined(__MC68K__) || defined(__powerc))
-    #define __Mac__     1
-    #define PT_BIGENDIAN    1
-  #endif
-#endif
-
-
 #ifndef __Mac_OSX__
     #if defined(__APPLE_CC__)
         #define __Mac_OSX__			1
@@ -72,34 +75,26 @@ typedef unsigned char Boolean;
 // Use FSSpec on Macs as Path-specifyers, else strings
 #define PATH_SEP							'/'
 
-#ifdef __Mac__
-        //#include  <Files.h> // commented by Kekus Digital
-#include <Carbon/Carbon.h>      // added by Kekus Digital
-#define			fullPath							FSSpec
-#undef  PATH_SEP
-#define PATH_SEP									':'
-
-#else // __Mac__, use ANSI-filefunctions
-
 #ifdef _WIN32
-#ifndef __NO_SYSTEM__
-#include <windows.h>            // including this causes problems with libjpeg
-#endif
-#define MAX_PATH_LENGTH		260
+    #ifndef __NO_SYSTEM__
+        #include <windows.h>            // including this causes problems with libjpeg
+    #endif
+
+    #define MAX_PATH_LENGTH		260
                 // was MAX_PATH
-#undef  PATH_SEP
-#define PATH_SEP							'\\'
+    #undef  PATH_SEP
+    #define PATH_SEP							'\\'
+
 #else
-#define MAX_PATH_LENGTH		512
+    #define MAX_PATH_LENGTH		512
 #endif
 
+// I really want to get rid of this one. it is legacy from OS 9
 typedef struct
 {
     char name[MAX_PATH_LENGTH];
 } fullPath;
 
-#endif
-
 
 // Some important defaults (perhaps to be moved somewhere else later
 
@@ -186,7 +181,7 @@ enum
 
 struct correct_Prefs
 {                               //  Preferences structure for tool correct
-    pt_uint32 magic;            //  File validity check, must be 20
+    uint32_t magic;            //  File validity check, must be 20
     int radial;                 //  Radial correction requested?
     double radial_params[3][5]; //  3 colors x (4 coeffic. for 3rd order polys + correction radius)
     int vertical;               //  Vertical shift requested ?
@@ -203,11 +198,12 @@ struct correct_Prefs
     double tilt_z;             //  tilt on z values
     double tilt_scale;         //  scale for tilting
 
-    int trans;                  //  traslation of camera plane requested?
+    int trans;                  //  translation of camera plane requested?
     double trans_x;            //  x component of translation vector
     double trans_y;            //  y component of translation vector
     double trans_z;             //  z component of translation vector
-
+    double trans_yaw;          // yaw of remapping plane for translation
+    double trans_pitch;        // pitch of remapping plane for translation
 
     int test;                  //  these parameters are for testing new projections
     double test_p0;            //  and make it easier for others to experiment
@@ -217,8 +213,8 @@ struct correct_Prefs
 
 
     int resize;                 //  scaling requested ?
-    pt_int32 width;             //  new width
-    pt_int32 height;            //  new height
+    uint32_t width;             //  new width
+    uint32_t height;            //  new height
     int luminance;              //  correct luminance variation?
     double lum_params[3];       //  parameters for luminance corrections
     int correction_mode;        //  0 - radial correction;1 - vertical correction;2 - deregistration
@@ -284,7 +280,10 @@ enum
     _equipanini = 22,
     _biplane = 23,
    _triplane = 24,
-    _panini_general = 25
+    _panini_general = 25,
+    _thoby   = 26,             // generalizes the model found in modern fisheye lenses. It is
+                               // parametrizable but it defaults to the Nikkor 10.5 fisheye lens
+    _hammer = 27,
 };
 
 enum
@@ -306,12 +305,14 @@ enum
     PANO_FORMAT_ORTHOGRAPHIC = 14,
     PANO_FORMAT_EQUISOLID = 15,
     PANO_FORMAT_EQUI_PANINI = 16,
-	PANO_FORMAT_BIPLANE = 17,
-	PANO_FORMAT_TRIPLANE = 18,
-	PANO_FORMAT_PANINI_GENERAL = 19,
+    PANO_FORMAT_BIPLANE = 17,
+    PANO_FORMAT_TRIPLANE = 18,
+    PANO_FORMAT_PANINI_GENERAL = 19,
+    PANO_FORMAT_THOBY   = 20,
+    PANO_FORMAT_HAMMER  = 21,
 };
 
-#define PANO_FORMAT_COUNT 20
+#define PANO_FORMAT_COUNT 22
 
 enum
 {                               // Enumerates external number of image f<index>
@@ -324,37 +325,38 @@ enum
     IMAGE_FORMAT_FISHEYE_ORTHOGRAPHIC = 8,
     IMAGE_FORMAT_FISHEYE_STEREOGRAPHIC = 10,
     IMAGE_FORMAT_FISHEYE_EQUISOLID = 21,
+    IMAGE_FORMAT_FISHEYE_THOBY = PANO_FORMAT_THOBY,
 };
-#define IMAGE_FORMAT_COUNT 9
+#define IMAGE_FORMAT_COUNT 10
 
 // A large rectangle
 
 typedef struct
 {
-    pt_int32 top;
-    pt_int32 bottom;
-    pt_int32 left;
-    pt_int32 right;
+    int32_t top;
+    int32_t bottom;
+    int32_t left;
+    int32_t right;
 } PTRect;
 
 typedef struct
 {
-    pt_int32 full_width;
-    pt_int32 full_height;
-    pt_int32 cropped_width;
-    pt_int32 cropped_height;
-    pt_int32 x_offset;
-    pt_int32 y_offset;
+    uint32_t full_width;
+    uint32_t full_height;
+    uint32_t cropped_width;
+    uint32_t cropped_height;
+    uint32_t x_offset;
+    uint32_t y_offset;
 } CropInfo;
 
 typedef struct
 {
-    pt_int32 fullWidth;
-    pt_int32 fullHeight;
-    pt_int32 croppedWidth;
-    pt_int32 croppedHeight;
-    pt_int32 xOffset;
-    pt_int32 yOffset;
+    uint32_t fullWidth;
+    uint32_t fullHeight;
+    uint32_t croppedWidth;
+    uint32_t croppedHeight;
+    uint32_t xOffset;
+    uint32_t yOffset;
 } pano_CropInfo;
 
 typedef struct
@@ -365,7 +367,7 @@ typedef struct
 
 typedef struct
 {
-    pt_int32 size;
+    uint32_t size;
     char *data;
 } pano_ICCProfile;
 
@@ -406,8 +408,6 @@ typedef struct
     int bitsPerPixel;           // This is a common value to use
 } pano_ImageMetadata;
 
-#define PANO_PATH_LEN 255
-
 // THe following constants define the number of parameters used by a projection
 
 // THe first is the number provided by the user. In most cases it is
@@ -426,14 +426,14 @@ typedef struct
 struct Image
 {
     // Pixel data
-    pt_int32 width;
-    pt_int32 height;
-    pt_int32 bytesPerLine;
-    pt_int32 bitsPerPixel;      // Must be 24 or 32
+    uint32_t width;
+    uint32_t height;
+    uint32_t bytesPerLine;
+    uint32_t bitsPerPixel;      // Must be 24 or 32
     size_t dataSize;
     unsigned char **data;
-    pt_int32 dataformat;        // rgb, Lab etc
-    pt_int32 format;            // Projection: rectilinear etc
+    int32_t dataformat;        // rgb, Lab etc
+    int32_t format;            // Projection: rectilinear etc
     int formatParamCount;       // Number of format parameters.
     double formatParam[PANO_PROJECTION_MAX_PARMS];  // Parameters for format.
     int precomputedCount;   // number of values precomputed for a given pano
@@ -443,7 +443,7 @@ struct Image
     double pitch;
     double roll;
     cPrefs cP;                  // How to correct the image
-    char name[PANO_PATH_LEN+1];
+    char name[MAX_PATH_LENGTH];
     PTRect selection;
     CropInfo cropInformation; // TO BE DEPRECATED
 
@@ -458,17 +458,17 @@ struct TrformStr                // This structure holds all image information
 {
     Image          *src;        // Source image, must be supplied on entry
     Image          *dest;       // Destination image data, valid if success = 1 
-    pt_int32        success;    // 0 - no, 1 - yes 
+    int32_t        success;    // 0 - no, 1 - yes 
 
 
-    pt_int32        tool;       // Panorama Tool requested
-    pt_int32        mode;       // how to run transformation
+    int32_t        tool;       // Panorama Tool requested
+    int32_t        mode;       // how to run transformation
     void           *data;       // data for tool requested.
     // Required only if mode = _usedata; then it
     // must point to valid preferences structure
     // for requested tool (see filter.h).
 
-    pt_int32        interpolator;// Select interpolator
+    int32_t        interpolator;// Select interpolator
     double          gamma;      // Gamma value for internal gamma correction
     int             fastStep;   // 0 no fast Transformation (default), FAST_TRANSFORM_STEP_MORPH, FAST_TRANSFORM_STEP_NORMAL
 };
@@ -510,18 +510,16 @@ typedef struct
     pano_projection_parameter parm[PANO_PROJECTION_MAX_PARMS]; 
 } pano_projection_features;
 
-int panoProjectionFeaturesQuery(int projection, pano_projection_features *features);
-int panoProjectionFormatCount(void);
+PANO13_IMPEX int panoProjectionFeaturesQuery(int projection, pano_projection_features *features);
+PANO13_IMPEX int panoProjectionFormatCount(void);
 /** APIs to read dynamic features that depend on projection parameters
     projection argument is an index, same as for queryFeatures()
 **/
-int queryFOVLimits( int projection,	
+PANO13_IMPEX int queryFOVLimits( int projection,	
 				    double * params, /* length depends on projection */
 					double * lims	/* [0] = maxhfov, [1] = maxvfov */
 				  );
 
-
-
 //void filter_main();
 
 #include "PTcommon.h"
